@@ -4,7 +4,7 @@ decoder.c
 diStorm3 - Powerful disassembler for X86/AMD64
 http://ragestorm.net/distorm/
 distorm at gmail dot com
-Copyright (C) 2003-2018 Gil Dabah
+Copyright (C) 2003-2020 Gil Dabah
 This library is licensed under the BSD license. See the file COPYING.
 */
 
@@ -511,7 +511,7 @@ _DecodeResult decode_internal(_CodeInfo* _ci, int supportOldIntr, _DInst result[
 			code += prefixSize;
 			codeOffset += prefixSize;
 
-			/* If we got only prefixes continue to next instruction. */
+			/* If we got only prefixes continue to next instruction, note that DF_SINGLE_BYTE_STEP is ignored here. */
 			if (prefixSize == INST_MAXIMUM_SIZE) continue;
 		}
 
@@ -585,14 +585,27 @@ _DecodeResult decode_internal(_CodeInfo* _ci, int supportOldIntr, _DInst result[
 				prefixSize -= 1;
 				codeLen += 1;
 			}
+			/* DF_SINGLE_BYTE_STEP is ignored here. */
 			ps.last = ps.start + prefixSize - 1;
 			code = ps.last + 1;
 			codeOffset = startInstOffset + prefixSize;
 		} else {
 			/* Advance to next instruction. */
-			codeLen -= pdi->size;
-			codeOffset += pdi->size;
-			code += pdi->size;
+
+			if (!(_ci->features & DF_SINGLE_BYTE_STEP)) { /* Start with the more likely happy flow. */
+				codeLen -= pdi->size;
+				codeOffset += pdi->size;
+				code += pdi->size;
+			} else {
+				/* Skip one byte only, so ignore the prefixes read. */
+				codeLen += prefixSize - 1;
+				codeOffset = codeOffset - prefixSize + 1;
+				code = code - prefixSize + 1;
+
+				/* Keep ci in sync. */
+				ci.code = code;
+				ci.codeLen = codeLen;
+			}
 
 			/* Instruction's size should include prefixes. */
 			pdi->size += (uint8_t)prefixSize;
@@ -631,18 +644,24 @@ _DecodeResult decode_internal(_CodeInfo* _ci, int supportOldIntr, _DInst result[
 		/* Fix next offset. */
 		_ci->nextOffset = codeOffset;
 
-		/* Check whether we need to stop on any flow control instruction. */
+		/* Check whether we need to stop on any feature. */
 		features = _ci->features;
-		mfc = META_GET_FC(pdi->meta);
-		if ((decodeResult == DECRES_SUCCESS) && (features & DF_STOP_ON_FLOW_CONTROL)) {
-			if (((features & DF_STOP_ON_CALL) && (mfc == FC_CALL)) ||
-				((features & DF_STOP_ON_RET) && (mfc == FC_RET)) ||
-				((features & DF_STOP_ON_SYS) && (mfc == FC_SYS)) ||
-				((features & DF_STOP_ON_UNC_BRANCH) && (mfc == FC_UNC_BRANCH)) ||
-				((features & DF_STOP_ON_CND_BRANCH) && (mfc == FC_CND_BRANCH)) ||
-				((features & DF_STOP_ON_INT) && (mfc == FC_INT)) ||
-				((features & DF_STOP_ON_CMOV) && (mfc == FC_CMOV)))
-				return DECRES_SUCCESS;
+		if (decodeResult == DECRES_SUCCESS) {
+			if ((features & DF_STOP_ON_PRIVILEGED) && (FLAG_GET_PRIVILEGED(pdi->flags))) return DECRES_SUCCESS;
+
+			if (features & DF_STOP_ON_FLOW_CONTROL) {
+				mfc = META_GET_FC(pdi->meta);
+				if (((features & DF_STOP_ON_CALL) && (mfc == FC_CALL)) ||
+					((features & DF_STOP_ON_RET) && (mfc == FC_RET)) ||
+					((features & DF_STOP_ON_SYS) && (mfc == FC_SYS)) ||
+					((features & DF_STOP_ON_UNC_BRANCH) && (mfc == FC_UNC_BRANCH)) ||
+					((features & DF_STOP_ON_CND_BRANCH) && (mfc == FC_CND_BRANCH)) ||
+					((features & DF_STOP_ON_INT) && (mfc == FC_INT)) ||
+					((features & DF_STOP_ON_CMOV) && (mfc == FC_CMOV)) ||
+					((features & DF_STOP_ON_HLT) && (mfc == FC_HLT))) {
+						return DECRES_SUCCESS;
+				}
+			}
 		}
 	}
 
